------------------------------------------------------------------------------
--                                                                          --
--                            GNATPP COMPONENTS                             --
--                                                                          --
--     A S I S _ U L . S O U R C E _ T A B L E . P R O C E S S I N G .      --
--                      A S I S _ P R O C E S S I N G                       --
--                                                                          --
--              (adapted for gnatpp from ASIS Utility Library)              --
--                                                                          --
--                                 B o d y                                  --
--                                                                          --
--                     Copyright (C) 2009-2013, AdaCore                     --
--                                                                          --
-- GNATPP is free software; you can redistribute it  and/or modify it under --
-- terms of the  GNU General Public License as published  by the Free Soft- --
-- ware  Foundation;  either version 2,  or (at your option) any later ver- --
-- sion.  GNATPP is  distributed in the  hope that it will  be  useful, but --
-- WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABI- --
-- LITY or  FITNESS  FOR A  PARTICULAR  PURPOSE. See the GNU General Public --
-- License  for more details. You  should  have  received a copy of the GNU --
-- General Public License  distributed with GNAT; see file COPYING. If not, --
-- write to the Free Software Foundation,  51 Franklin Street, Fifth Floor, --
-- Boston,                                                                  --
--                                                                          --
-- GNATPP is maintained by AdaCore (http://www.adacore.com)                 --
--                                                                          --
------------------------------------------------------------------------------

with GNATPP.Output;
with GNATPP.Processing;

with Ada.Exceptions;
with Ada.Wide_Text_IO;
with Ada_Trees;
with Ada_Trees.Self_Rep;
with Ada_Trees.Asis_To_Tree;
with Ada_Trees.Formatting;
with ASIS_UL.String_Utilities;
with GNATPP.Options;
with GNATPP.Common; use GNATPP.Common;
with ASIS_UL.Formatted_Output; use ASIS_UL.Formatted_Output; -- ???

separate (ASIS_UL.Source_Table.Processing)
procedure ASIS_Processing (CU : Asis.Compilation_Unit; SF : SF_Id) is
   Success : Boolean;
begin
   Set_Current_SF (SF);
   GNATPP.Output.Set_Output (SF, Success);
   pragma Assert (Success);

   --  ???Use_New_PP is True if we should use the new version of gnatpp
   --  implemented by Ada_Trees. Currently, it is False by default, and set to
   --  True by the "--pp-new" switch. When the new version is ready, we plan to
   --  change the default to True, and use the "--pp-old" switch to set it to
   --  False. Eventually, once we've been through a complete release cycle with
   --  Use_New_PP defaulting to True, we plan to remove the flag and the
   --  switchese. We can then remove the GNATPP.Processing package and
   --  pretty much everything it calls.

   if GNATPP.Options.Use_New_PP then
      declare
         use Ada_Trees, Ada_Trees.Asis_To_Tree, Ada_Trees.Formatting;
         use ASIS_UL.String_Utilities;
         Tree : constant Ada_Tree_Base := Compilation_Unit_To_Tree (CU);
         --  In case Free_Tree is changed to null-out its parameter, we don't
         --  want to check the predicate of Tree afterward.
         Source_File_Contents : String_Access := Read_File (Source_Name (SF));
      begin
         if Ada_Trees.Debug_Mode then
            Ada_Trees.Self_Rep.Put_Ada_Tree (Tree);
            Put ("\n");
         end if;

         Tree_To_Ada
           (Tree, Source_File_Contents.all,
            GNATPP.Options.The_Formatting_Options);
         Set_Source_Status (SF, Processed);
         Free (Source_File_Contents);
         Free_Tree (Tree);

         if Ada.Wide_Text_IO.Is_Open (Result_Out_File) then
            Ada.Wide_Text_IO.Close (Result_Out_File);
         end if;

      exception
         when X : others =>
            if Ada.Wide_Text_IO.Is_Open (Result_Out_File) then
               Ada.Wide_Text_IO.Close (Result_Out_File);
            end if;

            Set_Source_Status (SF, Error_Detected);
            Put ("\1", Ada.Exceptions.Exception_Information (X));
            Ada_Trees.Self_Rep.Put_Ada_Tree (Tree);
            Put ("\n");
            raise;
      end;

   --  Use old pretty printer

   else
      GNATPP.Processing.Pretty_Print (CU, SF);
   end if;
end ASIS_Processing;
